@@ -16,33 +16,33 @@ from datetime import datetime
 from typing import Any, Dict, List
 
 from .literals import (
-    AutoRollbackEvent,
-    BundleType,
-    ComputePlatform,
-    DeploymentCreator,
-    DeploymentOption,
-    DeploymentReadyAction,
-    DeploymentStatus,
-    DeploymentTargetType,
-    DeploymentType,
-    EC2TagFilterType,
-    ErrorCode,
-    FileExistsBehavior,
-    GreenFleetProvisioningAction,
-    InstanceAction,
-    InstanceStatus,
-    InstanceType,
-    LifecycleErrorCode,
-    LifecycleEventStatus,
-    MinimumHealthyHostsType,
-    OutdatedInstancesStrategy,
-    RevisionLocationType,
-    StopStatus,
-    TagFilterType,
-    TargetLabel,
-    TargetStatus,
-    TrafficRoutingType,
-    TriggerEventType,
+    AutoRollbackEventType,
+    BundleTypeType,
+    ComputePlatformType,
+    DeploymentCreatorType,
+    DeploymentOptionType,
+    DeploymentReadyActionType,
+    DeploymentStatusType,
+    DeploymentTargetTypeType,
+    DeploymentTypeType,
+    EC2TagFilterTypeType,
+    ErrorCodeType,
+    FileExistsBehaviorType,
+    GreenFleetProvisioningActionType,
+    InstanceActionType,
+    InstanceStatusType,
+    InstanceTypeType,
+    LifecycleErrorCodeType,
+    LifecycleEventStatusType,
+    MinimumHealthyHostsTypeType,
+    OutdatedInstancesStrategyType,
+    RevisionLocationTypeType,
+    StopStatusType,
+    TagFilterTypeType,
+    TargetLabelType,
+    TargetStatusType,
+    TrafficRoutingTypeType,
+    TriggerEventTypeType,
 )
 
 if sys.version_info >= (3, 8):
@@ -180,7 +180,7 @@ ApplicationInfoTypeDef = TypedDict(
         "createTime": datetime,
         "linkedToGitHub": bool,
         "gitHubAccountName": str,
-        "computePlatform": ComputePlatform,
+        "computePlatform": ComputePlatformType,
     },
     total=False,
 )
@@ -189,7 +189,7 @@ AutoRollbackConfigurationTypeDef = TypedDict(
     "AutoRollbackConfigurationTypeDef",
     {
         "enabled": bool,
-        "events": List[AutoRollbackEvent],
+        "events": List[AutoRollbackEventType],
     },
     total=False,
 )
@@ -276,7 +276,7 @@ BlueGreenDeploymentConfigurationTypeDef = TypedDict(
 BlueInstanceTerminationOptionTypeDef = TypedDict(
     "BlueInstanceTerminationOptionTypeDef",
     {
-        "action": InstanceAction,
+        "action": InstanceActionType,
         "terminationWaitTimeInMinutes": int,
     },
     total=False,
@@ -289,7 +289,7 @@ CloudFormationTargetTypeDef = TypedDict(
         "targetId": str,
         "lastUpdatedAt": datetime,
         "lifecycleEvents": List["LifecycleEventTypeDef"],
-        "status": TargetStatus,
+        "status": TargetStatusType,
         "resourceType": str,
         "targetVersionWeight": float,
     },
@@ -351,7 +351,7 @@ DeploymentConfigInfoTypeDef = TypedDict(
         "deploymentConfigName": str,
         "minimumHealthyHosts": "MinimumHealthyHostsTypeDef",
         "createTime": datetime,
-        "computePlatform": ComputePlatform,
+        "computePlatform": ComputePlatformType,
         "trafficRoutingConfig": "TrafficRoutingConfigTypeDef",
     },
     total=False,
@@ -373,14 +373,14 @@ DeploymentGroupInfoTypeDef = TypedDict(
         "alarmConfiguration": "AlarmConfigurationTypeDef",
         "autoRollbackConfiguration": "AutoRollbackConfigurationTypeDef",
         "deploymentStyle": "DeploymentStyleTypeDef",
-        "outdatedInstancesStrategy": OutdatedInstancesStrategy,
+        "outdatedInstancesStrategy": OutdatedInstancesStrategyType,
         "blueGreenDeploymentConfiguration": "BlueGreenDeploymentConfigurationTypeDef",
         "loadBalancerInfo": "LoadBalancerInfoTypeDef",
         "lastSuccessfulDeployment": "LastDeploymentInfoTypeDef",
         "lastAttemptedDeployment": "LastDeploymentInfoTypeDef",
         "ec2TagSet": "EC2TagSetTypeDef",
         "onPremisesTagSet": "OnPremisesTagSetTypeDef",
-        "computePlatform": ComputePlatform,
+        "computePlatform": ComputePlatformType,
         "ecsServices": List["ECSServiceTypeDef"],
     },
     total=False,
@@ -395,14 +395,14 @@ DeploymentInfoTypeDef = TypedDict(
         "deploymentId": str,
         "previousRevision": "RevisionLocationTypeDef",
         "revision": "RevisionLocationTypeDef",
-        "status": DeploymentStatus,
+        "status": DeploymentStatusType,
         "errorInformation": "ErrorInformationTypeDef",
         "createTime": datetime,
         "startTime": datetime,
         "completeTime": datetime,
         "deploymentOverview": "DeploymentOverviewTypeDef",
         "description": str,
-        "creator": DeploymentCreator,
+        "creator": DeploymentCreatorType,
         "ignoreApplicationStopFailures": bool,
         "autoRollbackConfiguration": "AutoRollbackConfigurationTypeDef",
         "updateOutdatedInstancesOnly": bool,
@@ -413,9 +413,9 @@ DeploymentInfoTypeDef = TypedDict(
         "blueGreenDeploymentConfiguration": "BlueGreenDeploymentConfigurationTypeDef",
         "loadBalancerInfo": "LoadBalancerInfoTypeDef",
         "additionalDeploymentStatusInfo": str,
-        "fileExistsBehavior": FileExistsBehavior,
+        "fileExistsBehavior": FileExistsBehaviorType,
         "deploymentStatusMessages": List[str],
-        "computePlatform": ComputePlatform,
+        "computePlatform": ComputePlatformType,
         "externalId": str,
         "relatedDeployments": "RelatedDeploymentsTypeDef",
     },
@@ -438,7 +438,7 @@ DeploymentOverviewTypeDef = TypedDict(
 DeploymentReadyOptionTypeDef = TypedDict(
     "DeploymentReadyOptionTypeDef",
     {
-        "actionOnTimeout": DeploymentReadyAction,
+        "actionOnTimeout": DeploymentReadyActionType,
         "waitTimeInMinutes": int,
     },
     total=False,
@@ -447,8 +447,8 @@ DeploymentReadyOptionTypeDef = TypedDict(
 DeploymentStyleTypeDef = TypedDict(
     "DeploymentStyleTypeDef",
     {
-        "deploymentType": DeploymentType,
-        "deploymentOption": DeploymentOption,
+        "deploymentType": DeploymentTypeType,
+        "deploymentOption": DeploymentOptionType,
     },
     total=False,
 )
@@ -456,7 +456,7 @@ DeploymentStyleTypeDef = TypedDict(
 DeploymentTargetTypeDef = TypedDict(
     "DeploymentTargetTypeDef",
     {
-        "deploymentTargetType": DeploymentTargetType,
+        "deploymentTargetType": DeploymentTargetTypeType,
         "instanceTarget": "InstanceTargetTypeDef",
         "lambdaTarget": "LambdaTargetTypeDef",
         "ecsTarget": "ECSTargetTypeDef",
@@ -468,7 +468,7 @@ DeploymentTargetTypeDef = TypedDict(
 DiagnosticsTypeDef = TypedDict(
     "DiagnosticsTypeDef",
     {
-        "errorCode": LifecycleErrorCode,
+        "errorCode": LifecycleErrorCodeType,
         "scriptName": str,
         "message": str,
         "logTail": str,
@@ -481,7 +481,7 @@ EC2TagFilterTypeDef = TypedDict(
     {
         "Key": str,
         "Value": str,
-        "Type": EC2TagFilterType,
+        "Type": EC2TagFilterTypeType,
     },
     total=False,
 )
@@ -511,7 +511,7 @@ ECSTargetTypeDef = TypedDict(
         "targetArn": str,
         "lastUpdatedAt": datetime,
         "lifecycleEvents": List["LifecycleEventTypeDef"],
-        "status": TargetStatus,
+        "status": TargetStatusType,
         "taskSetsInfo": List["ECSTaskSetTypeDef"],
     },
     total=False,
@@ -527,7 +527,7 @@ ECSTaskSetTypeDef = TypedDict(
         "status": str,
         "trafficWeight": float,
         "targetGroup": "TargetGroupInfoTypeDef",
-        "taskSetLabel": TargetLabel,
+        "taskSetLabel": TargetLabelType,
     },
     total=False,
 )
@@ -543,7 +543,7 @@ ELBInfoTypeDef = TypedDict(
 ErrorInformationTypeDef = TypedDict(
     "ErrorInformationTypeDef",
     {
-        "code": ErrorCode,
+        "code": ErrorCodeType,
         "message": str,
     },
     total=False,
@@ -639,7 +639,7 @@ GitHubLocationTypeDef = TypedDict(
 GreenFleetProvisioningOptionTypeDef = TypedDict(
     "GreenFleetProvisioningOptionTypeDef",
     {
-        "action": GreenFleetProvisioningAction,
+        "action": GreenFleetProvisioningActionType,
     },
     total=False,
 )
@@ -663,10 +663,10 @@ InstanceSummaryTypeDef = TypedDict(
     {
         "deploymentId": str,
         "instanceId": str,
-        "status": InstanceStatus,
+        "status": InstanceStatusType,
         "lastUpdatedAt": datetime,
         "lifecycleEvents": List["LifecycleEventTypeDef"],
-        "instanceType": InstanceType,
+        "instanceType": InstanceTypeType,
     },
     total=False,
 )
@@ -677,10 +677,10 @@ InstanceTargetTypeDef = TypedDict(
         "deploymentId": str,
         "targetId": str,
         "targetArn": str,
-        "status": TargetStatus,
+        "status": TargetStatusType,
         "lastUpdatedAt": datetime,
         "lifecycleEvents": List["LifecycleEventTypeDef"],
-        "instanceLabel": TargetLabel,
+        "instanceLabel": TargetLabelType,
     },
     total=False,
 )
@@ -703,7 +703,7 @@ LambdaTargetTypeDef = TypedDict(
         "deploymentId": str,
         "targetId": str,
         "targetArn": str,
-        "status": TargetStatus,
+        "status": TargetStatusType,
         "lastUpdatedAt": datetime,
         "lifecycleEvents": List["LifecycleEventTypeDef"],
         "lambdaFunctionInfo": "LambdaFunctionInfoTypeDef",
@@ -715,7 +715,7 @@ LastDeploymentInfoTypeDef = TypedDict(
     "LastDeploymentInfoTypeDef",
     {
         "deploymentId": str,
-        "status": DeploymentStatus,
+        "status": DeploymentStatusType,
         "endTime": datetime,
         "createTime": datetime,
     },
@@ -729,7 +729,7 @@ LifecycleEventTypeDef = TypedDict(
         "diagnostics": "DiagnosticsTypeDef",
         "startTime": datetime,
         "endTime": datetime,
-        "status": LifecycleEventStatus,
+        "status": LifecycleEventStatusType,
     },
     total=False,
 )
@@ -838,7 +838,7 @@ LoadBalancerInfoTypeDef = TypedDict(
 MinimumHealthyHostsTypeDef = TypedDict(
     "MinimumHealthyHostsTypeDef",
     {
-        "type": MinimumHealthyHostsType,
+        "type": MinimumHealthyHostsTypeType,
         "value": int,
     },
     total=False,
@@ -911,7 +911,7 @@ RevisionInfoTypeDef = TypedDict(
 RevisionLocationTypeDef = TypedDict(
     "RevisionLocationTypeDef",
     {
-        "revisionType": RevisionLocationType,
+        "revisionType": RevisionLocationTypeType,
         "s3Location": "S3LocationTypeDef",
         "gitHubLocation": "GitHubLocationTypeDef",
         "string": "RawStringTypeDef",
@@ -935,7 +935,7 @@ S3LocationTypeDef = TypedDict(
     {
         "bucket": str,
         "key": str,
-        "bundleType": BundleType,
+        "bundleType": BundleTypeType,
         "version": str,
         "eTag": str,
     },
@@ -945,7 +945,7 @@ S3LocationTypeDef = TypedDict(
 StopDeploymentOutputTypeDef = TypedDict(
     "StopDeploymentOutputTypeDef",
     {
-        "status": StopStatus,
+        "status": StopStatusType,
         "statusMessage": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
@@ -956,7 +956,7 @@ TagFilterTypeDef = TypedDict(
     {
         "Key": str,
         "Value": str,
-        "Type": TagFilterType,
+        "Type": TagFilterTypeType,
     },
     total=False,
 )
@@ -1036,7 +1036,7 @@ TrafficRouteTypeDef = TypedDict(
 TrafficRoutingConfigTypeDef = TypedDict(
     "TrafficRoutingConfigTypeDef",
     {
-        "type": TrafficRoutingType,
+        "type": TrafficRoutingTypeType,
         "timeBasedCanary": "TimeBasedCanaryTypeDef",
         "timeBasedLinear": "TimeBasedLinearTypeDef",
     },
@@ -1048,7 +1048,7 @@ TriggerConfigTypeDef = TypedDict(
     {
         "triggerName": str,
         "triggerTargetArn": str,
-        "triggerEvents": List[TriggerEventType],
+        "triggerEvents": List[TriggerEventTypeType],
     },
     total=False,
 )
